==> jc-1.4.0.tar.gz: soot/jimple/toolkits/invoke/InlinerSafetyManager.h <==
// public class soot.jimple.toolkits.invoke.InlinerSafetyManager

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f8b463c2d487e98 soot_jimple_toolkits_invoke_InlinerSafetyManager

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_invoke_InlinerSafetyManager_H_
#define _JC_soot_jimple_toolkits_invoke_InlinerSafetyManager_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_SootClass$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_InvokeExpr$object;
struct _jc_soot_jimple_Stmt$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$sub_refs	_jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$sub_refs;
typedef struct _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$sub_nonrefs	_jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$refs	_jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$refs;
typedef struct _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$nonrefs	_jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$nonrefs;
typedef struct _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$object	_jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$object;

typedef const struct _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$vmethods	_jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$vmethods;
typedef const struct _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$vtable	_jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$vtable;
typedef const struct _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$vtype	_jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$object *);

// Static methods
extern jboolean _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$method$canSafelyInlineInto$fff0eb89e64336e9(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_soot_SootMethod$object *);
extern jboolean _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$method$ensureInlinability$7b6fccc7f3b58208(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_soot_SootMethod$object *, struct _jc_java_lang_String$object *);
extern jboolean _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$method$invokeThrowsAccessErrorIn$ddcb051c70663b31(_jc_env *, struct _jc_soot_SootClass$object *, struct _jc_soot_SootMethod$object *, struct _jc_soot_SootMethod$object *);
extern jboolean _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$method$specialInvokePerformsLookupIn$97f7a7f91ae40ace(_jc_env *, struct _jc_object *, struct _jc_soot_SootClass$object *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$vmethods {
};

// Vtable
struct _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$vmethods	soot_jimple_toolkits_invoke_InlinerSafetyManager;
};

// Vtype
struct _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$refs {
    _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$sub_refs	soot_jimple_toolkits_invoke_InlinerSafetyManager;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$sub_nonrefs	soot_jimple_toolkits_invoke_InlinerSafetyManager;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$object {
	_jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$vtype	*vtype;
	_jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$vtype _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_invoke_InlinerSafetyManager, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$class_object;

#endif	/* _JC_soot_jimple_toolkits_invoke_InlinerSafetyManager_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/invoke/InlinerSafetyManager.h <==
// public class soot.jimple.toolkits.invoke.InlinerSafetyManager

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f8b463c2d487e98 soot_jimple_toolkits_invoke_InlinerSafetyManager

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_invoke_InlinerSafetyManager_H_
#define _JC_soot_jimple_toolkits_invoke_InlinerSafetyManager_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_SootClass$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_InvokeExpr$object;
struct _jc_soot_jimple_Stmt$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$sub_refs	_jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$sub_refs;
typedef struct _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$sub_nonrefs	_jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$refs	_jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$refs;
typedef struct _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$nonrefs	_jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$nonrefs;
typedef struct _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$object	_jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$object;

typedef const struct _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$vmethods	_jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$vmethods;
typedef const struct _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$vtable	_jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$vtable;
typedef const struct _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$vtype	_jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$object *) _JC_JCNI_ATTR;

// Static methods
extern jboolean _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$method$canSafelyInlineInto$fff0eb89e64336e9(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_soot_SootMethod$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$method$ensureInlinability$7b6fccc7f3b58208(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_soot_SootMethod$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$method$invokeThrowsAccessErrorIn$ddcb051c70663b31(_jc_env *, struct _jc_soot_SootClass$object *, struct _jc_soot_SootMethod$object *, struct _jc_soot_SootMethod$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$method$specialInvokePerformsLookupIn$97f7a7f91ae40ace(_jc_env *, struct _jc_object *, struct _jc_soot_SootClass$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$vmethods {
};

// Vtable
struct _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$vmethods	soot_jimple_toolkits_invoke_InlinerSafetyManager;
};

// Vtype
struct _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$refs {
    _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$sub_refs	soot_jimple_toolkits_invoke_InlinerSafetyManager;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$sub_nonrefs	soot_jimple_toolkits_invoke_InlinerSafetyManager;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$object {
	_jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$vtype	*vtype;
	_jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$vtype _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_invoke_InlinerSafetyManager, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_invoke_InlinerSafetyManager$class_object;

#endif	/* _JC_soot_jimple_toolkits_invoke_InlinerSafetyManager_H_ */
